/* Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.model.uinfo;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;

import org.dive4elements.river.model.River;

/**
 * Hibernate binding for the DB table salix
 *
 * @author Matthias Schäfer
 *
 */

@Entity
@Table(name = "salix")
public class Salix implements Serializable {

    /***** FIELDS *****/

    private static final long serialVersionUID = -2765661962829259970L;

    private Integer id;

    private River river;

    private String filename;

    private String kmrange_info;

    private String notes;

    private String evaluation_by;

    private List<SalixValue> values;


    /***** CONSTRUCTORS *****/

    public Salix() {
    }


    public Salix(final River river, final String filename, final String kmrange_info, final String notes, final String evaluation_by) {
        this.river = river;
        this.filename = filename;
        this.kmrange_info = kmrange_info;
        this.notes = notes;
        this.evaluation_by = evaluation_by;
        this.values = new ArrayList<>();
    }

    /***** METHODS *****/

    @Id
    @SequenceGenerator(name = "SEQUENCE_SALIX_ID_SEQ", sequenceName = "SALIX_ID_SEQ", allocationSize = 1)
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "SEQUENCE_SALIX_ID_SEQ")
    @Column(name = "id")
    public Integer getId() {
        return this.id;
    }

    public void setId(final Integer id) {
        this.id = id;
    }

    @OneToOne
    @JoinColumn(name = "river_id")
    public River getRiver() {
        return this.river;
    }

    public void setRiver(final River river) {
        this.river = river;
    }

    @Column(name = "filename")
    public String getFilename() {
        return this.filename;
    }

    public void setFilename(final String filename) {
        this.filename = filename;
    }

    @Column(name = "kmrange_info")
    public String getKmrange_info() {
        return this.kmrange_info;
    }

    public void setKmrange_info(final String kmrange_info) {
        this.kmrange_info = kmrange_info;
    }

    @Column(name = "notes")
    public String getNotes() {
        return this.notes;
    }

    public void setNotes(final String notes) {
        this.notes = notes;
    }

    @Column(name = "evaluation_by")
    public String getEvaluation_by() {
        return this.evaluation_by;
    }

    public void setEvaluation_by(final String evaluation_by) {
        this.evaluation_by = evaluation_by;
    }

    @OneToMany
    @JoinColumn(name = "salix_id")
    public List<SalixValue> getValues() {
        return this.values;
    }

    public void setValues(final List<SalixValue> values) {
        this.values = values;
    }

    public void addValue(final SalixValue value) {
        this.values.add(value);
    }
}